@@ -3,28 +3,29 @@ from sympy import *
 
 def main():
     """
-    from IPython.display import IFrame
-    from urllib.request import urlopen
-    from zipfile import ZipFile
-    from io import BytesIO
+from IPython.display import IFrame
+from urllib.request import urlopen
+from zipfile import ZipFile
+from io import BytesIO
 
-    extract_to = './data'
+extract_to = './data'
 
 
-    def open_pdf(q, ex):
-        return IFrame(f'{extract_to}/{q}-{ex}.pdf', 600, 300)
+def open_pdf(q, ex):
+    return IFrame(f'{extract_to}/{q}-{ex}.pdf', 600, 300)
 
 
-    def download_and_unzip(url, extract_to='.'):
-        http_response = urlopen(url)
-        zipfile = ZipFile(BytesIO(http_response.read()))
-        zipfile.extractall(path=extract_to)
+def download_and_unzip(url, extract_to='.'):
+    http_response = urlopen(url)
+    zipfile = ZipFile(BytesIO(http_response.read()))
+    zipfile.extractall(path=extract_to)
 
 
-    url = 'https://drive.google.com/u/0/uc?id=1Q1e1ovKOn_5jzO7k1E_P8ikTIdW7DhhQ&export=download'
+url = 'https://drive.google.com/u/0/uc?id=1Q1e1ovKOn_5jzO7k1E_P8ikTIdW7DhhQ&export=download'
 
-    download_and_unzip(url, extract_to='.')
-    """
+download_and_unzip(url, extract_to='.')
+"""
+    pass
 
 
 def get_inversions(d: dict):
